//=============================================================================
// ANNAMutator. (C) 2012 "Dei" & Nobody. Edits by Cozmo, 2020
//
//  Mutator which is responisble for the replacing of all required Actors in
// the map at the game begin *and* while summoning.
//=============================================================================
class ANNAMutator extends CBPMutator;

//#exec OBJ LOAD FILE="..\System\DXWeapon2.u"
//#exec OBJ LOAD FILE="..\System\ANNAExt.u"

var class<Inventory> toReplace[30]; //list of clases that the replacer is supposed to look for
var class<Inventory> replaceTo[30]; //list of classes that the replacer is supposed to replace with
var ANNAGameMode AGM;

/**
  Modified, so it just accepts one mutator of that class in the mutator list.
*/
function AddMutator(Mutator M)
{
    if(M.Class != class)
      super.AddMutator(M);
}

function PostBeginPlay()
{
	local UdpServerQuery UdpQuery;

    Super.PostBeginPlay();
}

/**
  Checks the Actor which is given by the parameter <i>in</i> and eventually replaces it.
  Since the parameter is declared with the <b>out</b> modifier, the changing of the parameter
  <i>in</i> will directly effect the Actor given by the <i>in</i> parameter.
*/
function ReplaceMapItem (out Actor in, Class<Actor> inClass)
{
    local Inventory inv, weapon;
    local int i;
    local int length;
    local bool bFound;

    if(Inventory(in) != none)
    {
        for(i=0;  i < ArrayCount(toReplace) ; i++)
        {
            if(inClass == toReplace[i])
            {
                bFound=true;
                break;
            }
        }
		
        if(bFound)
        {
            inv=Spawn(replaceTO[i],in.owner,in.tag,in.location,in.Rotation);
			
            if(inv != none)
            {
                inv.SetPhysics(in.Physics);
                inv.RespawnTime=Inventory(in).RespawnTime;
                in.Destroy();
                in = inv;
            }
        }
    }
	
    Super.ReplaceMapItem (in, inClass);
    
    if(in.isA('AmmoCrate') || in.isA('Inventory') || in.isA('Robot') || in.isA('DeusExDecoration')) // Rightfully stolen from miniMTL.. should decrease network load?
    {
        in.bAlwaysRelevant = False;
		
        if(in.isA('Weapon'))
        {
            weapon = Weapon(in);
			
            if(weapon != None)
            {
                if(!weapon.bHeldItem && !weapon.bTossedOut && weapon.Owner == None) // Make sure we only change it for weapons that are on the wall, and not (previously) owned by anyone.
                {
                    weapon.NetUpdateFrequency = 5.00; // Only send 5 updates per second, instead of default 100.
                }
            }
        }
    }
}

/**
  Right spawns <i>ReplaceMapItem()</i>, because the right summoned Actor can be replaced like all required Actors at the begin too.
*/
function SpawnNotification (out Actor in, Class<Actor> inClass)
{
    ReplaceMapItem(in, inClass);
    Super.SpawnNotification(in, inClass);
}

/*
function bool CheckReplacement(actor Other, out byte bSuperRelevant)
{
	return !ReplaceWith(Other, string(other.Class));
}*/

DefaultProperties
{
/*
	toReplace(0)='DeusEx.WeaponAssaultGun'
	toReplace(1)='DeusEx.WeaponAssaultShotgun'
	toReplace(2)='DeusEx.WeaponBaton'
	toReplace(3)='DeusEx.WeaponCombatKnife'
	toReplace(4)='DeusEx.WeaponCrowbar'
	toReplace(5)='DeusEx.WeaponEMPGrenade'
	toReplace(6)='DeusEx.FireExtinguisher'
	toReplace(7)='DeusEx.WeaponFlameThrower'
	toReplace(8)='DeusEx.WeaponGasGrenade'
	toReplace(9)='DeusEx.WeaponGEPGun'
	toReplace(10)='DeusEx.WeaponHideAGun'
	toReplace(11)='DeusEx.WeaponLAM'
	toReplace(12)='DeusEx.WeaponLAW'
	toReplace(13)='DeusEx.WeaponMiniCrossbow'
	toReplace(14)='DeusEx.WeaponMJ12Commando'
	toReplace(15)='DeusEx.WeaponMJ12Rocket'
	toReplace(16)='DeusEx.WeaponNanoSword'
	toReplace(17)='DeusEx.WeaponNanoVirusGrenade'
	toReplace(18)='DeusEx.WeaponPepperGun'
	toReplace(19)='DeusEx.WeaponPistol'
	toReplace(20)='DeusEx.WeaponPlasmaRifle'
	toReplace(21)='DeusEx.WeaponProd'
	toReplace(22)='DeusEx.WeaponRifle'
	toReplace(23)='DeusEx.WeaponSawedOff'
	toReplace(24)='DeusEx.WeaponShuriken'
	toReplace(25)='DeusEx.WeaponStealthPistol'
	toReplace(26)='DeusEx.WeaponSword'
	replaceTo(0)=class'DXWeapon2.WeaponAssaultGun2'
	replaceTo(1)=class'DXWeapon2.WeaponAssaultShotgun2'
	replaceTo(2)=class'DXWeapon2.WeaponBaton2'
	replaceTo(3)=class'DXWeapon2.WeaponCombatKnife2'
	replaceTo(4)=class'DXWeapon2.WeaponCrowbar2'
	replaceTo(5)=class'DXWeapon2.WeaponEMPGrenade2'
	replaceTo(6)=class'DXWeapon2.WeaponFireExtinguisher2'
	replaceTo(7)=class'DXWeapon2.WeaponFlameThrower2'
	replaceTo(8)=class'DXWeapon2.WeaponGasGrenade2'
	replaceTo(9)=class'DXWeapon2.WeaponGEPGun2'
	replaceTo(10)=class'DXWeapon2.WeaponHideAGun2'
	replaceTo(11)=class'DXWeapon2.WeaponLAM2'
	replaceTo(12)=class'DXWeapon2.WeaponLAW2'
	replaceTo(13)=class'DXWeapon2.WeaponMiniCrossbow2'
	replaceTo(14)=class'DXWeapon2.WeaponMJ12Commando2'
	replaceTo(15)=class'DXWeapon2.WeaponMJ12Rocket2'
	replaceTo(16)=class'DXWeapon2.WeaponNanoSword2'
	replaceTo(17)=class'DXWeapon2.WeaponNanoVirusGrenade2'
	replaceTo(18)=class'DXWeapon2.WeaponPepperGun2'
	replaceTo(19)=class'DXWeapon2.WeaponPistol2'
	replaceTo(20)=class'DXWeapon2.WeaponPlasmaRifle2'
	replaceTo(21)=class'DXWeapon2.WeaponProd2'
	replaceTo(22)=class'DXWeapon2.WeaponRifle2'
	replaceTo(23)=class'DXWeapon2.WeaponSawedOffShotgun2'
	replaceTo(24)=class'DXWeapon2.WeaponShuriken2'
	replaceTo(25)=class'DXWeapon2.WeaponStealthPistol2'
	replaceTo(26)=class'DXWeapon2.WeaponSword2'
*/
}
